==> debug-level-2.0.2.tgz: package/lib/quick-format.js <==
"use strict";

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

/**
 * @credits quick-format-unescaped
 * @license The MIT License (MIT)
 * @copyright Copyright (c) 2016-2019 David Mark Clements
 */
function tryStringify(o) {
  try {
    return JSON.stringify(o);
  } catch (e) {
    return '"[Circular]"';
  }
}

module.exports = format;

function format(f, args, opts) {
  var obj = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
  var ss = opts && opts.stringify || tryStringify;
  var argLen = args.length;
  var a = 0;
  var str = '';

  var type = _typeof(f);

  var procObj = function procObj(val) {
    if (Array.isArray(val)) {
      Object.assign(obj, {
        arr: val
      });
    } else if (val instanceof Error) {
      // } else if (val.stack && val.message && val.name) {
      if (!str) str = val.message;
      Object.assign(obj, {
        err: val
      });
    } else {
      var name = val.name,
          level = val.level,
          other = _objectWithoutProperties(val, ["name", "level"]);

      Object.assign(obj, other);
    }
  };

  if (type === 'function') {
    str = toFunctionSting(f.name);
  } else if (type === 'object' && f !== null) {
    str = f.msg || '';
    procObj(f);
  } else if (type !== 'string') {
    str = String(f);
  } else if (type === 'string') {
    if (argLen === 0) return f;
    var lastPos = -1;
    var flen = f && f.length || 0;

    for (var i = 0; i < flen;) {
      if (f.charCodeAt(i) === 37 && i + 1 < flen) {
        lastPos = lastPos > -1 ? lastPos : 0;

        switch (f.charCodeAt(i + 1)) {
          case 100: // 'd'

          case 102:
            // 'f'
            if (a >= argLen) {
              break;
            }

            if (lastPos < i) {
              str += f.slice(lastPos, i);
            }

            if (args[a] == null) break;
            str += Number(args[a]);
            lastPos = i = i + 2;
            break;

          case 105:
            // 'i'
            if (a >= argLen) {
              break;
            }

            if (lastPos < i) {
              str += f.slice(lastPos, i);
            }

            if (args[a] == null) break;
            str += Math.floor(Number(args[a]));
            lastPos = i = i + 2;
            break;

          case 79: // 'O'

          case 111: // 'o'

          case 106:
            {
              // 'j'
              if (a >= argLen) {
                break;
              }

              if (lastPos < i) {
                str += f.slice(lastPos, i);
              }

              if (args[a] === undefined) break;

              var _type = _typeof(args[a]);

              if (_type === 'string') {
                str += '\'' + args[a] + '\'';
                lastPos = i + 2;
                i++;
                break;
              }

              if (_type === 'function') {
                str += toFunctionSting(args[a].name);
                lastPos = i + 2;
                i++;
                break;
              }

              str += ss(args[a]);
              lastPos = i + 2;
              i++;
              break;
            }

          case 115:
            // 's'
            if (a >= argLen) {
              break;
            }

            if (lastPos < i) {
              str += f.slice(lastPos, i);
            }

            str += String(args[a]);
            lastPos = i + 2;
            i++;
            break;

          case 37:
            // '%'
            if (lastPos < i) {
              str += f.slice(lastPos, i);
            }

            str += '%';
            lastPos = i + 2;
            i++;
            a--; // stay on same argument

            break;
        }

        ++a;
      }

      ++i;
    }

    if (lastPos === -1) {
      str = f;
    } else if (lastPos < flen) {
      str += f.slice(lastPos);
    }
  }

  for (a; a < argLen; a++) {
    var val = args[a];

    var _type2 = _typeof(val);

    if (_type2 === 'function') {
      str += ' ' + toFunctionSting(val.name);
    } else if (_type2 === 'object' && val !== null) {
      procObj(val);
    } else {
      str += ' ' + String(val);
    }
  }

  return str;
}

var toFunctionSting = function toFunctionSting(name) {
  return (name || '<anonymous>') + '()';
};

==> debug-level-2.1.1.tgz: package/lib/quick-format.js <==
"use strict";

var _excluded = ["name", "level"];

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

/**
 * @credits quick-format-unescaped
 * @license The MIT License (MIT)
 * @copyright Copyright (c) 2016-2019 David Mark Clements
 */
function tryStringify(o) {
  try {
    return JSON.stringify(o);
  } catch (e) {
    return '"[Circular]"';
  }
}

module.exports = format;

function format(f, args, opts) {
  var obj = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
  var ss = opts && opts.stringify || tryStringify;
  var argLen = args.length;
  var a = 0;
  var str = '';

  var type = _typeof(f);

  var procObj = function procObj(val) {
    if (Array.isArray(val)) {
      Object.assign(obj, {
        arr: val
      });
    } else if (val instanceof Error) {
      // } else if (val.stack && val.message && val.name) {
      if (!str) str = val.message;
      Object.assign(obj, {
        err: val
      });
    } else {
      var name = val.name,
          level = val.level,
          other = _objectWithoutProperties(val, _excluded);

      Object.assign(obj, other);
    }
  };

  if (type === 'function') {
    str = toFunctionSting(f.name);
  } else if (type === 'object' && f !== null) {
    str = f.msg || '';
    procObj(f);
  } else if (type !== 'string') {
    str = String(f);
  } else if (type === 'string') {
    if (argLen === 0) return f;
    var lastPos = -1;
    var flen = f && f.length || 0;

    for (var i = 0; i < flen;) {
      if (f.charCodeAt(i) === 37 && i + 1 < flen) {
        lastPos = lastPos > -1 ? lastPos : 0;

        switch (f.charCodeAt(i + 1)) {
          case 100: // 'd'

          case 102:
            // 'f'
            if (a >= argLen) {
              break;
            }

            if (lastPos < i) {
              str += f.slice(lastPos, i);
            }

            if (args[a] == null) break;
            str += Number(args[a]);
            lastPos = i = i + 2;
            break;

          case 105:
            // 'i'
            if (a >= argLen) {
              break;
            }

            if (lastPos < i) {
              str += f.slice(lastPos, i);
            }

            if (args[a] == null) break;
            str += Math.floor(Number(args[a]));
            lastPos = i = i + 2;
            break;

          case 79: // 'O'

          case 111: // 'o'

          case 106:
            {
              // 'j'
              if (a >= argLen) {
                break;
              }

              if (lastPos < i) {
                str += f.slice(lastPos, i);
              }

              if (args[a] === undefined) break;

              var _type = _typeof(args[a]);

              if (_type === 'string') {
                str += '\'' + args[a] + '\'';
                lastPos = i + 2;
                i++;
                break;
              }

              if (_type === 'function') {
                str += toFunctionSting(args[a].name);
                lastPos = i + 2;
                i++;
                break;
              }

              str += ss(args[a]);
              lastPos = i + 2;
              i++;
              break;
            }

          case 115:
            // 's'
            if (a >= argLen) {
              break;
            }

            if (lastPos < i) {
              str += f.slice(lastPos, i);
            }

            str += String(args[a]);
            lastPos = i + 2;
            i++;
            break;

          case 37:
            // '%'
            if (lastPos < i) {
              str += f.slice(lastPos, i);
            }

            str += '%';
            lastPos = i + 2;
            i++;
            a--; // stay on same argument

            break;
        }

        ++a;
      }

      ++i;
    }

    if (lastPos === -1) {
      str = f;
    } else if (lastPos < flen) {
      str += f.slice(lastPos);
    }
  }

  for (a; a < argLen; a++) {
    var val = args[a];

    var _type2 = _typeof(val);

    if (_type2 === 'function') {
      str += ' ' + toFunctionSting(val.name);
    } else if (_type2 === 'object' && val !== null) {
      procObj(val);
    } else {
      str += ' ' + String(val);
    }
  }

  return str;
}

var toFunctionSting = function toFunctionSting(name) {
  return (name || '<anonymous>') + '()';
};
